<?php
// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

// Add the settings page to the WordPress admin menu
function interworky_assistant_add_admin_menu() {
    add_menu_page(
        esc_html__('Interworky Settings', 'interworky-assistant'),
        esc_html__('Interworky Assistant', 'interworky-assistant'),
        'manage_options',
        'interworky_settings',
        'interworky_assistant_settings_page',
        'dashicons-admin-generic',
        65
    );
}
add_action('admin_menu', 'interworky_assistant_add_admin_menu');

// Register settings with proper sanitization
function interworky_assistant_register_settings() {
    // Register the API Key setting
    register_setting(
        'interworky_settings_group',
        'interworky_api_key',
        [
            'type'              => 'string',
            'sanitize_callback' => 'sanitize_text_field', // Ensure proper sanitization
            'default'           => '',
        ]
    );

    // Register the Visibility setting
    register_setting(
        'interworky_settings_group',
        'interworky_visibility',
        [
            'type'              => 'string',
            'sanitize_callback' => 'interworky_assistant_sanitize_visibility',
            'default'           => 'all',
        ]
    );

    // Register the Page Paths setting
    register_setting(
        'interworky_settings_group',
        'interworky_page_paths',
        [
            'type'              => 'string',
            'sanitize_callback' => 'interworky_assistant_sanitize_page_paths',
            'default'           => '',
        ]
    );
}
add_action('admin_init', 'interworky_assistant_register_settings');

// Sanitization for visibility setting
function interworky_assistant_sanitize_visibility($input) {
    $valid_options = ['all', 'include', 'exclude'];
    return in_array($input, $valid_options, true) ? $input : 'all';
}

// Sanitization for page paths (only add slashes when non-empty)
function interworky_assistant_sanitize_page_paths($input) {
    $input = wp_unslash($input); // Unslash before processing

    if (empty(trim($input))) {
        return ''; // Return empty string if no input
    }

    // Ensure paths are safe and properly formatted
    $paths = array_map('trim', explode(',', $input));

    $sanitized_paths = array_filter(array_map(function ($path) {
        $path = sanitize_text_field($path);
        return '/' . trim($path, '/') . '/'; // Ensure leading and trailing slashes
    }, $paths));

    return implode(',', $sanitized_paths);
}

// Show admin notice if API Key is missing
function interworky_assistant_admin_notice() {
    if (empty(get_option('interworky_api_key'))) {
        echo '<div class="notice notice-error"><p>' 
            . esc_html__('Interworky API Key is missing. Please add it in', 'interworky-assistant') 
            . ' <a href="admin.php?page=interworky_settings">' . esc_html__('Settings', 'interworky-assistant') . '</a>.</p></div>';
    }
}
add_action('admin_notices', 'interworky_assistant_admin_notice');

// Plugin settings page content
function interworky_assistant_settings_page() {
    $api_key = get_option('interworky_api_key', '');
    $visibility = get_option('interworky_visibility', 'all');
    $page_paths = get_option('interworky_page_paths', '');

    ?>
    <div class="wrap">
        <h1><?php esc_html_e('Interworky Assistant Settings', 'interworky-assistant'); ?></h1>
        <form method="post" action="options.php">
            <?php settings_fields('interworky_settings_group'); ?>
            <?php do_settings_sections('interworky_settings_group'); ?>

            <h2><?php esc_html_e('API Key', 'interworky-assistant'); ?></h2>
            <p>
                <?php esc_html_e('Find your API Key in your', 'interworky-assistant'); ?>
                <a href="https://interworky.com/dashboard/tutorial" target="_blank"><?php esc_html_e('Interworky Integration Page', 'interworky-assistant'); ?></a>.
            </p>
            <input type="text" name="interworky_api_key" value="<?php echo $api_key; ?>" placeholder="<?php esc_attr_e('Enter your Interworky API Key', 'interworky-assistant'); ?>" style="width: 400px;">

            <h2><?php esc_html_e('Chatbot Display Options', 'interworky-assistant'); ?></h2>
            <select name="interworky_visibility">
                <option value="all" <?php selected($visibility, 'all'); ?>><?php esc_html_e('Show on all pages', 'interworky-assistant'); ?></option>
                <option value="include" <?php selected($visibility, 'include'); ?>><?php esc_html_e('Show only on these pages', 'interworky-assistant'); ?></option>
                <option value="exclude" <?php selected($visibility, 'exclude'); ?>><?php esc_html_e('Hide on these pages', 'interworky-assistant'); ?></option>
            </select>

            <h3><?php esc_html_e('List of Page Paths (comma-separated)', 'interworky-assistant'); ?></h3>
            <p><strong><?php esc_html_e('Examples:', 'interworky-assistant'); ?></strong> <?php esc_html_e('/about, /contact, /pricing', 'interworky-assistant'); ?></p>
            <textarea name="interworky_page_paths" rows="3" style="width: 400px;"><?php echo esc_textarea($page_paths); ?></textarea>

            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Add a settings link under the plugin name in the Plugins page
function interworky_assistant_add_settings_link($links) {
    $settings_link = '<a href="admin.php?page=interworky_assistant_settings">Settings</a>';
    array_push($links, $settings_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'interworky_assistant_add_settings_link');

